@@ -1,7 +1,4 @@
 
-from tqdm import tqdm
-import numpy as np
-from multiprocessing import cpu_count
 
 import tensorflow as tf
 
@@ -47,7 +44,7 @@ def train_eval_input_fn(params, mode='train'):
     if mode == 'train':
         dataset = dataset.shuffle(params.shuffle_buffer)
 
-    dataset = dataset.prefetch(params.prefetch)
+    dataset = dataset.prefetch(tf.data.experimental.AUTOTUNE)
     if params.dynamic_padding:
         dataset = dataset.apply(
             tf.data.experimental.bucket_by_sequence_length(
