@@ -1,11 +1,10 @@
+import json
 import os
 import re
-import json
 import shutil
 
 from .modeling import BertConfig
-
-from .utils import create_path, EOS_TOKEN, get_or_make_label_encoder
+from .utils import EOS_TOKEN, create_path
 
 
 class BaseParams():
@@ -31,6 +30,8 @@ class BaseParams():
         self.detail_log = True
 
         self.multiprocess = True
+        self.num_cpus = 4
+        self.per_cpu_buffer = 3000
         self.decode_vocab_file = None
         self.eval_throttle_secs = 600
 
